pub struct RebuildSpec {
pub head: Option<usize>,
pub tail: Option<usize>,
}Expand description
Constraints to re-apply when the source content has been replaced wholesale
(--live). The line index is rebuilt from scratch each time, so caps that
were originally honored at startup need to be reasserted.
Fields
head: Option<usize>tail: Option<usize>Trait Implementations
Sourceimpl Clone for RebuildSpec
impl Clone for RebuildSpec
Sourcefn clone(&self) -> RebuildSpec
fn clone(&self) -> RebuildSpec
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Default for RebuildSpec
impl Default for RebuildSpec
Sourcefn default() -> RebuildSpec
fn default() -> RebuildSpec
Returns the “default value” for a type. Read more
impl Copy for RebuildSpec