pub struct BatchSpec {
pub destination: BatchDestination,
pub follow: bool,
pub poll_interval: Duration,
}Fields
destination: BatchDestinationfollow: boolWhen true, after the initial pass keep polling the source for new bytes and append matching lines until SIGTERM/SIGHUP arrives.
poll_interval: DurationPoll cadence for follow mode. 250 ms matches the interactive loop.