pub struct TermGraphics {
pub kitty: bool,
pub sixel: bool,
pub cell_px: Option<(u16, u16)>,
}Expand description
What the terminal supports, plus its cell pixel size when reported.
Fields
kitty: boolsixel: boolcell_px: Option<(u16, u16)>Trait Implementations
Sourceimpl Clone for TermGraphics
impl Clone for TermGraphics
Sourcefn clone(&self) -> TermGraphics
fn clone(&self) -> TermGraphics
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for TermGraphics
Sourceimpl Debug for TermGraphics
impl Debug for TermGraphics
Sourceimpl Default for TermGraphics
impl Default for TermGraphics
Sourcefn default() -> TermGraphics
fn default() -> TermGraphics
Returns the “default value” for a type. Read more
impl Eq for TermGraphics
Sourceimpl PartialEq for TermGraphics
impl PartialEq for TermGraphics
Sourcefn eq(&self, other: &TermGraphics) -> bool
fn eq(&self, other: &TermGraphics) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for TermGraphics