Module viewport

Module viewport 

Structs

Frame
SearchState
Viewport

Enums

CaseMode
How --grep, --filter ~/!~, /, ?, and :tag patterns interpret case. Smart matches less / ripgrep / vim smartcase: a pattern with no uppercase characters is treated as case-insensitive; one with any uppercase character is case-sensitive.
QuitAtEof
Controls auto-exit on end-of-file. Off (default) never quits. Second (less -e) quits on the second forward-motion that lands at EOF in a row. First (less -E) quits the moment a forward motion lands at EOF.
RowStyle
SearchDirection