CaseMode

Enum CaseMode 

pub enum CaseMode {
    Sensitive,
    Smart,
    Insensitive,
}
How --grep, --filter ~/!~, /, ?, and :tag patterns interpret case. Smart matches less / ripgrep / vim smartcase: a pattern with no uppercase characters is treated as case-insensitive; one with any uppercase character is case-sensitive.

Variants



Sensitive



Smart



Insensitive

Implementations

Source

impl CaseMode

pub fn apply_to_pattern(self, pattern: &str) -> String

Compile this case policy into a regex pattern by prepending the (?i) inline flag when case-insensitive matching is desired.