Structs
- Rebuild
Spec - Constraints to re-apply when the source content has been replaced wholesale
(
--live). The line index is rebuilt from scratch each time, so caps that were originally honored at startup need to be reasserted.
--live). The line index is rebuilt from scratch each time, so caps that
were originally honored at startup need to be reasserted.